@@ -1,13 +1,10 @@
+/* $Id$ */
+
+#ifndef INCLUDED_CPL_CONFIG_EXTRAS
+#define INCLUDED_CPL_CONFIG_EXTRAS
 
 #if defined(__APPLE__)
 
-#ifdef __BIG_ENDIAN__
-  #define HOST_FILLORDER FILLORDER_MSB2LSB
-#else
-  #define HOST_FILLORDER FILLORDER_LSB2MSB
-#endif
-
-
 #ifdef __LP64__
   #define SIZEOF_UNSIGNED_LONG 8
 #else
@@ -26,7 +23,12 @@
   #undef WORDS_BIGENDIAN
 #endif
 
+#undef VSI_STAT64
+#undef VSI_STAT64_T
+
 #define VSI_STAT64 stat
 #define VSI_STAT64_T stat
 
-#endif
+#endif // APPLE
+
+#endif // INCLUDED_CPL_CONFIG_EXTRAS
