@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_proxy.h 4b46f534fed80d31c3e15c1517169f40694a4a3e 2021-10-14 19:17:37 +0200 Even Rouault $
+ * $Id$
  *
  * Project:  GDAL Core
  * Purpose:  GDAL Core C++/Private declarations
@@ -115,8 +115,8 @@ class CPL_DLL GDALProxyRasterBand : public GDALRasterBand
   protected:
     GDALProxyRasterBand() {}
 
-    virtual GDALRasterBand* RefUnderlyingRasterBand() = 0;
-    virtual void UnrefUnderlyingRasterBand(GDALRasterBand* poUnderlyingRasterBand);
+    virtual GDALRasterBand* RefUnderlyingRasterBand() const = 0;
+    virtual void UnrefUnderlyingRasterBand(GDALRasterBand* poUnderlyingRasterBand) const;
 
     CPLErr IReadBlock( int, int, void * ) override;
     CPLErr IWriteBlock( int, int, void * ) override;
@@ -195,6 +195,8 @@ class CPL_DLL GDALProxyRasterBand : public GDALRasterBand
     GDALRasterBand *GetMaskBand() override;
     int GetMaskFlags() override;
     CPLErr CreateMaskBand( int nFlags ) override;
+    bool            IsMaskBand() const override;
+    GDALMaskValueRange GetMaskValueRange() const override;
 
     CPLVirtualMem  *GetVirtualMemAuto( GDALRWFlag eRWFlag,
                                        int *pnPixelSpace,
@@ -326,12 +328,12 @@ class CPL_DLL GDALProxyPoolRasterBand : public GDALProxyRasterBand
     GDALProxyPoolOverviewRasterBand **papoProxyOverviewRasterBand = nullptr;
     GDALProxyPoolMaskBand            *poProxyMaskBand = nullptr;
 
-    GDALRasterBand* RefUnderlyingRasterBand( bool bForceOpen );
+    GDALRasterBand* RefUnderlyingRasterBand( bool bForceOpen ) const;
 
   protected:
-    GDALRasterBand* RefUnderlyingRasterBand() override;
+    GDALRasterBand* RefUnderlyingRasterBand() const override;
     void UnrefUnderlyingRasterBand( GDALRasterBand* poUnderlyingRasterBand )
-        override;
+        const override;
 
     friend class GDALProxyPoolOverviewRasterBand;
     friend class GDALProxyPoolMaskBand;
@@ -378,15 +380,15 @@ class GDALProxyPoolOverviewRasterBand : public GDALProxyPoolRasterBand
     GDALProxyPoolRasterBand *poMainBand = nullptr;
     int                      nOverviewBand = 0;
 
-    GDALRasterBand          *poUnderlyingMainRasterBand = nullptr;
-    int                      nRefCountUnderlyingMainRasterBand = 0;
+    mutable GDALRasterBand          *poUnderlyingMainRasterBand = nullptr;
+    mutable int                      nRefCountUnderlyingMainRasterBand = 0;
 
     CPL_DISALLOW_COPY_ASSIGN(GDALProxyPoolOverviewRasterBand)
 
   protected:
-    GDALRasterBand* RefUnderlyingRasterBand() override;
+    GDALRasterBand* RefUnderlyingRasterBand() const override;
     void UnrefUnderlyingRasterBand( GDALRasterBand* poUnderlyingRasterBand )
-        override;
+        const override;
 
   public:
     GDALProxyPoolOverviewRasterBand( GDALProxyPoolDataset* poDS,
@@ -405,15 +407,15 @@ class GDALProxyPoolMaskBand : public GDALProxyPoolRasterBand
   private:
     GDALProxyPoolRasterBand *poMainBand = nullptr;
 
-    GDALRasterBand          *poUnderlyingMainRasterBand = nullptr;
-    int                      nRefCountUnderlyingMainRasterBand = 0;
+    mutable GDALRasterBand          *poUnderlyingMainRasterBand = nullptr;
+    mutable int                      nRefCountUnderlyingMainRasterBand = 0;
 
     CPL_DISALLOW_COPY_ASSIGN(GDALProxyPoolMaskBand)
 
   protected:
-    GDALRasterBand* RefUnderlyingRasterBand() override;
+    GDALRasterBand* RefUnderlyingRasterBand() const override;
     void UnrefUnderlyingRasterBand( GDALRasterBand* poUnderlyingRasterBand )
-        override;
+        const override;
 
   public:
     GDALProxyPoolMaskBand( GDALProxyPoolDataset* poDS,
@@ -424,6 +426,8 @@ class GDALProxyPoolMaskBand : public GDALProxyPoolRasterBand
                            GDALDataType eDataType,
                            int nBlockXSize, int nBlockYSize );
     ~GDALProxyPoolMaskBand() override;
+
+    bool            IsMaskBand() const override { return true; }
 };
 
 #endif
