@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_featurestyle.h 16763 2009-04-14 09:57:15Z chaitanya $
+ * $Id$
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Define of Feature Representation
@@ -46,14 +46,17 @@ class OGRFeature;
  * All OGRStyleTool param lists are defined in ogr_core.h.
  */
 
+/** OGR Style type */
 typedef enum ogr_style_type
 {
+    OGRSTypeUnused = -1,
     OGRSTypeString,
     OGRSTypeDouble,
     OGRSTypeInteger,
     OGRSTypeBoolean
 }  OGRSType;
 
+//! @cond Doxygen_Suppress
 typedef struct ogr_style_param
 {
     int              eParam;
@@ -62,7 +65,6 @@ typedef struct ogr_style_param
     OGRSType         eType;
 } OGRStyleParamId;
 
-
 typedef struct ogr_style_value
 {
     char            *pszValue;
@@ -71,20 +73,23 @@ typedef struct ogr_style_value
     GBool            bValid;
     OGRSTUnitId      eUnit;
 } OGRStyleValue;
+//! @endcond
 
+// Every time a pszStyleString given in parameter is NULL,
+// the StyleString defined in the Mgr will be use.
 
-//Everytime a pszStyleString gived in parameter is NULL, 
-//    the StyleString defined in the Mgr will be use.
 /**
  * This class represents a style table
  */
 class CPL_DLL OGRStyleTable
 {
   private:
-    char **m_papszStyleTable;
+    char **m_papszStyleTable = nullptr;
 
-    CPLString osLastRequestedStyleName;
-    int iNextStyle;
+    CPLString osLastRequestedStyleName{};
+    int iNextStyle = 0;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleTable)
 
   public:
     OGRStyleTable();
@@ -92,7 +97,7 @@ class CPL_DLL OGRStyleTable
     GBool AddStyle(const char *pszName,const char *pszStyleString);
     GBool RemoveStyle(const char *pszName);
     GBool ModifyStyle(const char *pszName, const char *pszStyleString);
-    
+
     GBool SaveStyleTable(const char *pszFilename);
     GBool LoadStyleTable(const char *pszFilename);
     const char *Find(const char *pszStyleString);
@@ -106,7 +111,6 @@ class CPL_DLL OGRStyleTable
     const char *GetLastStyleName();
 };
 
-
 class OGRStyleTool;
 
 /**
@@ -115,42 +119,44 @@ class OGRStyleTool;
 class CPL_DLL OGRStyleMgr
 {
   private:
-    OGRStyleTable   *m_poDataSetStyleTable;
-    char            *m_pszStyleString;
+    OGRStyleTable   *m_poDataSetStyleTable = nullptr;
+    char            *m_pszStyleString = nullptr;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleMgr)
 
   public:
-    OGRStyleMgr(OGRStyleTable *poDataSetStyleTable = NULL);
+    explicit OGRStyleMgr(OGRStyleTable *poDataSetStyleTable = nullptr);
     ~OGRStyleMgr();
 
-    GBool SetFeatureStyleString(OGRFeature *,const char *pszStyleString=NULL,
+    GBool SetFeatureStyleString(OGRFeature *,const char *pszStyleString=nullptr,
                                 GBool bNoMatching = FALSE);
-    /*it will set in the gived feature the pszStyleString with 
-            the style or will set the style name found in 
-            dataset StyleTable (if bNoMatching == FALSE)*/
-              
+    /* It will set in the given feature the pszStyleString with
+            the style or will set the style name found in
+            dataset StyleTable (if bNoMatching == FALSE). */
+
     const char *InitFromFeature(OGRFeature *);
-    GBool InitStyleString(const char *pszStyleString = NULL);
-    
-    const char *GetStyleName(const char *pszStyleString= NULL);
+    GBool InitStyleString(const char *pszStyleString = nullptr);
+
+    const char *GetStyleName(const char *pszStyleString= nullptr);
     const char *GetStyleByName(const char *pszStyleName);
-    
-    GBool AddStyle(const char *pszStyleName, const char *pszStyleString=NULL);
-    
-    const char *GetStyleString(OGRFeature * = NULL);
- 
+
+    GBool AddStyle(const char *pszStyleName, const char *pszStyleString=nullptr);
+
+    const char *GetStyleString(OGRFeature * = nullptr);
+
     GBool AddPart(OGRStyleTool *);
     GBool AddPart(const char *);
 
-    int GetPartCount(const char *pszStyleString = NULL);
-    OGRStyleTool *GetPart(int hPartId, const char *pszStyleString = NULL);
-    
-    /*It could have a reference counting processus for the OGRStyleTable, if
-      needed */
-      
-    OGRStyleTable *GetDataSetStyleTable(){return m_poDataSetStyleTable;}
-    
-    OGRStyleTool *CreateStyleToolFromStyleString(const char *pszStyleString);
+    int GetPartCount(const char *pszStyleString = nullptr);
+    OGRStyleTool *GetPart(int hPartId, const char *pszStyleString = nullptr);
 
+    /* It could have a reference counting process us for the OGRStyleTable, if
+      needed. */
+//! @cond Doxygen_Suppress
+    OGRStyleTable *GetDataSetStyleTable(){return m_poDataSetStyleTable;}
+
+    OGRStyleTool *CreateStyleToolFromStyleString(const char *pszStyleString);
+//! @endcond
 };
 
 /**
@@ -159,49 +165,64 @@ class CPL_DLL OGRStyleMgr
 class CPL_DLL OGRStyleTool
 {
   private:
-    GBool m_bModified;
-    GBool m_bParsed;
-    double m_dfScale;
-    OGRSTUnitId m_eUnit;
-    OGRSTClassId m_eClassId;
-    char *m_pszStyleString;
+    GBool m_bModified = false;
+    GBool m_bParsed = false;
+    double m_dfScale = 1.0;
+    OGRSTUnitId m_eUnit = OGRSTUMM;
+    OGRSTClassId m_eClassId = OGRSTCNone;
+    char *m_pszStyleString = nullptr;
 
     virtual GBool Parse() = 0;
 
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleTool)
+
   protected:
+#ifndef DOXYGEN_SKIP
     GBool Parse(const OGRStyleParamId* pasStyle,
                 OGRStyleValue* pasValue,
                 int nCount);
+#endif
 
   public:
-    
-    OGRStyleTool(){}
-    OGRStyleTool(OGRSTClassId eClassId);
+
+    OGRStyleTool() :
+        m_bModified(FALSE),
+        m_bParsed(FALSE),
+        m_dfScale(0.0),
+        m_eUnit(OGRSTUGround),
+        m_eClassId(OGRSTCNone),
+        m_pszStyleString(nullptr)
+        {}
+    explicit OGRStyleTool(OGRSTClassId eClassId);
     virtual ~OGRStyleTool();
 
-    GBool GetRGBFromString(const char *pszColor, int &nRed, int &nGreen, 
+    static GBool GetRGBFromString(const char *pszColor, int &nRed, int &nGreen,
                            int &nBlue, int &nTransparence);
-    int   GetSpecificId(const char *pszId, const char *pszWanted);
+    static int   GetSpecificId(const char *pszId, const char *pszWanted);
 
+#ifndef DOXYGEN_SKIP
     GBool IsStyleModified() {return m_bModified;}
     void  StyleModified() {m_bModified = TRUE;}
 
     GBool IsStyleParsed() {return m_bParsed;}
     void  StyleParsed() {m_bParsed = TRUE;}
-    
+#endif
+
     OGRSTClassId GetType();
 
+#ifndef DOXYGEN_SKIP
     void SetInternalInputUnitFromParam(char *pszString);
-    
+#endif
+
     void SetUnit(OGRSTUnitId,double dfScale = 1.0); //the dfScale will be
          //used if we are working with Ground Unit ( ground = paper * scale);
 
     OGRSTUnitId GetUnit(){return m_eUnit;}
-    
-    /* It's existe two way to set the parameters in the Style, with generic
-methodes (using a defined enumeration) or with the reel method specific
-for Each style tools.*/
-    
+
+    // There are two way to set the parameters in the Style, with generic
+    // methods (using a defined enumeration) or with the reel method specific
+    // for Each style tools.
+
     virtual const char *GetStyleString() = 0;
     void SetStyleString(const char *pszStyleString);
     const char *GetStyleString(const OGRStyleParamId *pasStyleParam ,
@@ -218,11 +239,11 @@ for Each style tools.*/
     double GetParamDbl(const OGRStyleParamId &sStyleParam ,
                        OGRStyleValue &sStyleValue,
                        GBool &bValueIsNull);
-    
+
     void SetParamStr(const OGRStyleParamId &sStyleParam ,
                      OGRStyleValue &sStyleValue,
                      const char *pszParamString);
-    
+
     void SetParamNum(const OGRStyleParamId &sStyleParam ,
                      OGRStyleValue &sStyleValue,
                      int nParam);
@@ -230,12 +251,14 @@ for Each style tools.*/
     void SetParamDbl(const OGRStyleParamId &sStyleParam ,
                      OGRStyleValue &sStyleValue,
                      double dfParam);
-
+#ifndef DOXYGEN_SKIP
     double ComputeWithUnit(double, OGRSTUnitId);
     int    ComputeWithUnit(int , OGRSTUnitId);
-
+#endif
 };
 
+//! @cond Doxygen_Suppress
+
 /**
  * This class represents a style pen
  */
@@ -245,22 +268,24 @@ class CPL_DLL OGRStylePen : public OGRStyleTool
 
     OGRStyleValue    *m_pasStyleValue;
 
-    GBool Parse();
+    GBool Parse() override;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStylePen)
 
   public:
 
     OGRStylePen();
-    virtual ~OGRStylePen(); 
+    ~OGRStylePen() override;
 
     /**********************************************************************/
     /* Explicit fct for all parameters defined in the Drawing tools  Pen  */
     /**********************************************************************/
-     
+
     const char *Color(GBool &bDefault){return GetParamStr(OGRSTPenColor,bDefault);}
     void SetColor(const char *pszColor){SetParamStr(OGRSTPenColor,pszColor);}
     double Width(GBool &bDefault){return GetParamDbl(OGRSTPenWidth,bDefault);}
     void SetWidth(double dfWidth){SetParamDbl(OGRSTPenWidth,dfWidth);}
-    const char *Pattern(GBool &bDefault){return (char *)GetParamStr(OGRSTPenPattern,bDefault);}
+    const char *Pattern(GBool &bDefault){return GetParamStr(OGRSTPenPattern,bDefault);}
     void SetPattern(const char *pszPattern){SetParamStr(OGRSTPenPattern,pszPattern);}
     const char *Id(GBool &bDefault){return GetParamStr(OGRSTPenId,bDefault);}
     void SetId(const char *pszId){SetParamStr(OGRSTPenId,pszId);}
@@ -272,16 +297,16 @@ class CPL_DLL OGRStylePen : public OGRStyleTool
     void SetJoin(const char *pszJoin){SetParamStr(OGRSTPenJoin,pszJoin);}
     int  Priority(GBool &bDefault){return GetParamNum(OGRSTPenPriority,bDefault);}
     void SetPriority(int nPriority){SetParamNum(OGRSTPenPriority,nPriority);}
-    
+
     /*****************************************************************/
-    
+
     const char *GetParamStr(OGRSTPenParam eParam, GBool &bValueIsNull);
     int GetParamNum(OGRSTPenParam eParam,GBool &bValueIsNull);
     double GetParamDbl(OGRSTPenParam eParam,GBool &bValueIsNull);
     void SetParamStr(OGRSTPenParam eParam, const char *pszParamString);
     void SetParamNum(OGRSTPenParam eParam, int nParam);
     void SetParamDbl(OGRSTPenParam eParam, double dfParam);
-    const char *GetStyleString();
+    const char *GetStyleString() override;
 };
 
 /**
@@ -293,12 +318,14 @@ class CPL_DLL OGRStyleBrush : public OGRStyleTool
 
     OGRStyleValue    *m_pasStyleValue;
 
-    GBool Parse();
+    GBool Parse() override;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleBrush)
 
   public:
 
     OGRStyleBrush();
-    virtual ~OGRStyleBrush();
+    ~OGRStyleBrush() override;
 
     /* Explicit fct for all parameters defined in the Drawing tools Brush */
 
@@ -318,17 +345,16 @@ class CPL_DLL OGRStyleBrush : public OGRStyleTool
     void SetSpacingY(double dfY){SetParamDbl(OGRSTBrushDy,dfY  );}
     int  Priority(GBool &bDefault){ return GetParamNum(OGRSTBrushPriority,bDefault);}
     void SetPriority(int nPriority){ SetParamNum(OGRSTBrushPriority,nPriority);}
-    
 
     /*****************************************************************/
-    
+
      const char *GetParamStr(OGRSTBrushParam eParam, GBool &bValueIsNull);
      int GetParamNum(OGRSTBrushParam eParam,GBool &bValueIsNull);
      double GetParamDbl(OGRSTBrushParam eParam,GBool &bValueIsNull);
      void SetParamStr(OGRSTBrushParam eParam, const char *pszParamString);
      void SetParamNum(OGRSTBrushParam eParam, int nParam);
      void SetParamDbl(OGRSTBrushParam eParam, double dfParam);
-     const char *GetStyleString();
+     const char *GetStyleString() override;
 };
 
 /**
@@ -340,17 +366,19 @@ class CPL_DLL OGRStyleSymbol : public OGRStyleTool
 
     OGRStyleValue    *m_pasStyleValue;
 
-    GBool Parse();
+    GBool Parse() override;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleSymbol)
 
   public:
 
     OGRStyleSymbol();
-    virtual ~OGRStyleSymbol();
+    ~OGRStyleSymbol() override;
 
     /*****************************************************************/
     /* Explicit fct for all parameters defined in the Drawing tools  */
     /*****************************************************************/
-    
+
     const char *Id(GBool &bDefault){return GetParamStr(OGRSTSymbolId,bDefault);}
     void  SetId(const char *pszId){ SetParamStr(OGRSTSymbolId,pszId);}
     double Angle(GBool &bDefault){ return GetParamDbl(OGRSTSymbolAngle,bDefault);}
@@ -368,7 +396,7 @@ class CPL_DLL OGRStyleSymbol : public OGRStyleTool
     double Offset(GBool &bDefault){return GetParamDbl(OGRSTSymbolOffset,bDefault);}
     void SetOffset(double dfOffset){SetParamDbl(OGRSTSymbolOffset,dfOffset  );}
     double Perp(GBool &bDefault){return GetParamDbl(OGRSTSymbolPerp,bDefault);}
-    void SetPerp(double dfPerp){SetParamDbl(OGRSTSymbolPerp,dfPerp  );}  
+    void SetPerp(double dfPerp){SetParamDbl(OGRSTSymbolPerp,dfPerp  );}
     int  Priority(GBool &bDefault){return GetParamNum(OGRSTSymbolPriority,bDefault);}
     void SetPriority(int nPriority){SetParamNum(OGRSTSymbolPriority,nPriority);}
     const char *FontName(GBool &bDefault)
@@ -379,14 +407,14 @@ class CPL_DLL OGRStyleSymbol : public OGRStyleTool
     void SetOColor(const char *pszColor){SetParamStr(OGRSTSymbolOColor,pszColor);}
 
     /*****************************************************************/
-    
+
      const char *GetParamStr(OGRSTSymbolParam eParam, GBool &bValueIsNull);
      int GetParamNum(OGRSTSymbolParam eParam,GBool &bValueIsNull);
      double GetParamDbl(OGRSTSymbolParam eParam,GBool &bValueIsNull);
      void SetParamStr(OGRSTSymbolParam eParam, const char *pszParamString);
      void SetParamNum(OGRSTSymbolParam eParam, int nParam);
      void SetParamDbl(OGRSTSymbolParam eParam, double dfParam);
-     const char *GetStyleString();
+     const char *GetStyleString() override;
 };
 
 /**
@@ -398,17 +426,19 @@ class CPL_DLL OGRStyleLabel : public OGRStyleTool
 
     OGRStyleValue    *m_pasStyleValue;
 
-    GBool Parse();
+    GBool Parse() override;
+
+    CPL_DISALLOW_COPY_ASSIGN(OGRStyleLabel)
 
   public:
 
     OGRStyleLabel();
-    virtual ~OGRStyleLabel();
+    ~OGRStyleLabel() override;
 
     /*****************************************************************/
     /* Explicit fct for all parameters defined in the Drawing tools  */
     /*****************************************************************/
-    
+
     const char *FontName(GBool &bDefault){return GetParamStr(OGRSTLabelFontName,bDefault);}
     void  SetFontName(const char *pszFontName){SetParamStr(OGRSTLabelFontName,pszFontName);}
     double Size(GBool &bDefault){return GetParamDbl(OGRSTLabelSize,bDefault);}
@@ -430,7 +460,7 @@ class CPL_DLL OGRStyleLabel : public OGRStyleTool
     double SpacingY(GBool &bDefault){return GetParamDbl(OGRSTLabelDy,bDefault);}
     void SetSpacingY(double dfY){SetParamDbl(OGRSTLabelDy,dfY);}
     double Perp(GBool &bDefault){return GetParamDbl(OGRSTLabelPerp,bDefault);}
-    void SetPerp(double dfPerp){SetParamDbl(OGRSTLabelPerp,dfPerp);}  
+    void SetPerp(double dfPerp){SetParamDbl(OGRSTLabelPerp,dfPerp);}
     GBool Bold(GBool &bDefault){return GetParamNum(OGRSTLabelBold,bDefault);}
     void SetBold(GBool bBold){SetParamNum(OGRSTLabelBold,bBold);}
     GBool Italic(GBool &bDefault){return GetParamNum(OGRSTLabelItalic,bDefault);}
@@ -443,24 +473,22 @@ class CPL_DLL OGRStyleLabel : public OGRStyleTool
     void SetStrikeout(GBool bStrikeout){SetParamNum(OGRSTLabelStrikeout,bStrikeout);}
     double Stretch(GBool &bDefault){return GetParamDbl(OGRSTLabelStretch,bDefault);}
     void SetStretch(double dfStretch){SetParamDbl(OGRSTLabelStretch,dfStretch);}
-    const char *AdjustmentHor(GBool &bDefault){return GetParamStr(OGRSTLabelAdjHor,bDefault);}
-    void SetAdjustmentHor(const char *pszAdjustmentHor){SetParamStr(OGRSTLabelAdjHor,pszAdjustmentHor);}
-    const char *AdjustmentVert(GBool &bDefault){return GetParamStr(OGRSTLabelAdjVert,bDefault);}
-    void SetAdjustmentVert(const char *pszAdjustmentVert){SetParamStr(OGRSTLabelAdjHor,pszAdjustmentVert);}
     const char *ShadowColor(GBool &bDefault){return GetParamStr(OGRSTLabelHColor,bDefault);}
     void SetShadowColor(const char *pszShadowColor){SetParamStr(OGRSTLabelHColor,pszShadowColor);}
     const char *OutlineColor(GBool &bDefault){return GetParamStr(OGRSTLabelOColor,bDefault);}
     void SetOutlineColor(const char *pszOutlineColor){SetParamStr(OGRSTLabelOColor,pszOutlineColor);}
-    
+
     /*****************************************************************/
-    
+
      const char *GetParamStr(OGRSTLabelParam eParam, GBool &bValueIsNull);
      int GetParamNum(OGRSTLabelParam eParam,GBool &bValueIsNull);
      double GetParamDbl(OGRSTLabelParam eParam,GBool &bValueIsNull);
      void SetParamStr(OGRSTLabelParam eParam, const char *pszParamString);
      void SetParamNum(OGRSTLabelParam eParam, int nParam);
      void SetParamDbl(OGRSTLabelParam eParam, double dfParam);
-     const char *GetStyleString();
+     const char *GetStyleString() override;
 };
 
+//! @endcond
+
 #endif /* OGR_FEATURESTYLE_INCLUDE */
